summaryrefslogtreecommitdiffstats
path: root/src/tools
diff options
context:
space:
mode:
authorSachin Gupta <sgupta2m@in.ibm.com>2016-09-14 22:01:53 -0500
committerSachin Gupta <sgupta2m@in.ibm.com>2016-09-20 03:10:15 -0400
commitb2f9ed86c6874e77cb068d39027b225e21ef1bd4 (patch)
treefeefb3b98768815c233fffdee9569a2c6aae83bc /src/tools
parentfa2cdbdd901c973e30d6b035b4140b2731eb2305 (diff)
downloadtalos-sbe-b2f9ed86c6874e77cb068d39027b225e21ef1bd4.tar.gz
talos-sbe-b2f9ed86c6874e77cb068d39027b225e21ef1bd4.zip
Update cmvc script for releaseNotes
Change-Id: Idb8a9008789fcc6063594a1a0c8b6d9bf897c673 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/29737 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Shakeeb A. Pasha B K <shakeebbk@in.ibm.com> Reviewed-by: RAJA DAS <rajadas2@in.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Sachin Gupta <sgupta2m@in.ibm.com>
Diffstat (limited to 'src/tools')
-rwxr-xr-xsrc/tools/utils/sbeCmvcConstants.py6
-rwxr-xr-xsrc/tools/utils/sbeCmvcUtility.py5
-rwxr-xr-xsrc/tools/utils/sbePrime.py6
3 files changed, 13 insertions, 4 deletions
diff --git a/src/tools/utils/sbeCmvcConstants.py b/src/tools/utils/sbeCmvcConstants.py
index 124422a4..680d3b3b 100755
--- a/src/tools/utils/sbeCmvcConstants.py
+++ b/src/tools/utils/sbeCmvcConstants.py
@@ -66,8 +66,8 @@ SUCCESS_TRACK_STATE = 53
SUCCESS_CI_TRIGGER = 54
# This is a default files list to Check-in
-CMVC_FILE_LIST ="sbe_sp_intf.H,simics.tar,sbe_pibmem.bin,sbe_seeprom.bin"
-CMVC_FILE_UNDO_LIST ="src/sbei/sbfw/sbe_sp_intf.H src/sbei/sbfw/simics.tar src/sbei/sbfw/img/sbe_pibmem.bin src/sbei/sbfw/img/sbe_seeprom.bin"
+CMVC_FILE_LIST ="sbe_sp_intf.H,simics.tar,sbe_pibmem.bin,sbe_seeprom.bin,releaseNotes.html"
+CMVC_FILE_UNDO_LIST ="src/sbei/sbfw/sbe_sp_intf.H src/sbei/sbfw/simics.tar src/sbei/sbfw/img/sbe_pibmem.bin src/sbei/sbfw/img/sbe_seeprom.bin,src/sbei/sbfw/releaseNotes.html"
CMVC_DIR_CREATE ="sandbox_"
@@ -82,4 +82,4 @@ ERROR_SANDBOX_EXIST = 200 # Sandbox doesnt exist
ERROR_FILE_INPUT = 201 # User have entered no file
ERROR_BUILD_FAILED = 202 # Compilation failed
ERROR_HOOKING_FILE = 203 # Error while building shell hooks
-FILE_LOOKUP_LIST ="src/sbei/sbfw/sbe_sp_intf.H,src/sbei/sbfw/simics.tar,src/sbei/sbfw/img/sbe_pibmem.bin,src/sbei/sbfw/img/sbe_seeprom.bin"
+FILE_LOOKUP_LIST ="src/sbei/sbfw/sbe_sp_intf.H,src/sbei/sbfw/simics.tar,src/sbei/sbfw/img/sbe_pibmem.bin,src/sbei/sbfw/img/sbe_seeprom.bin,src/sbei/sbfw/releaseNotes.html"
diff --git a/src/tools/utils/sbePrime.py b/src/tools/utils/sbePrime.py
index bfbd8ab1..2d5bd764 100755
--- a/src/tools/utils/sbePrime.py
+++ b/src/tools/utils/sbePrime.py
@@ -51,6 +51,9 @@ import sbeCmvcConstants as errorcode
import sbeCmvcUtility as utilcode
import sbePatchUtility as utilpatch
+# Files to copy for sbe prime
+PRIME_FILE_LIST ="sbe_sp_intf.H,simics.tar,sbe_pibmem.bin,sbe_seeprom.bin"
+
#-------------------------
# Main Function
#-------------------------
@@ -241,6 +244,9 @@ def main():
#----------------------------------------
# Find the files and copy to the sanbox dir
# Just take a quick check if the Sandbox exist or not
+
+ if sim_patch == "None":
+ file_name = PRIME_FILE_LIST
if sandbox_path != "None":
if os.path.isdir(sandbox_path) == True:
rc_copy = utilcode.utilCopyFileToSandbox(path_name,sandbox_path,file_name)
OpenPOWER on IntegriCloud
diff --git a/src/tools/utils/sbeCmvcUtility.py b/src/tools/utils/sbeCmvcUtility.py
index 110a8e2c..424a97eb 100755
--- a/src/tools/utils/sbeCmvcUtility.py
+++ b/src/tools/utils/sbeCmvcUtility.py
@@ -173,9 +173,12 @@ def utilCmvcCheckout(i_filename, i_release, i_cmvcnum):
print " File Name\t: ",i_filename
print " Release\t: ",i_release
# The file simics.tar is not unique so provide the relative path
if i_filename == "simics.tar":
i_filename = 'src/sbei/sbfw/simics.tar'
+ elif i_filename == "releaseNotes.html":
+ i_filename = 'src/sbei/sbfw/releaseNotes.html'
print " CMVC #\t: ",i_cmvcnum[1:]
l_home_path= expanduser("~") + "/" + errorcode.CMVC_DIR_CREATE + i_cmvcnum
@@ -173,9 +173,12 @@ def utilCmvcCheckout(i_filename, i_release, i_cmvcnum):
print " File Name\t: ",i_filename
print " Release\t: ",i_release
- # The file simics.tar is not unique so provide the relative path
+ # The file simics.tar,releaseNotes.html is not unique so provide
+ # the relative path
if i_filename == "simics.tar":
i_filename = 'src/sbei/sbfw/simics.tar'